@@ -68,7 +68,7 @@ opt.decel.single.R<-function (yy, method="L-BFGS-B", hess = FALSE, pool = TRUE,
 
   init.par<-c(init.trait.var, init.cov.traits, anc.values, -1)
   lower.limit<-c(rep(0, length(init.trait.var)), rep(NA, (length(init.cov.traits) +length(anc.values))+1))
-  upper.limit<-c(rep(NA, (length(init.trait.var) + length(init.cov.traits)+ length(anc.values))), 0)
+  upper.limit<-c(rep(NA, (length(init.trait.var) + length(init.cov.traits)+ length(anc.values))), -1e-13)
 
 
   ### Start iterations from different starting values
@@ -87,7 +87,7 @@ opt.decel.single.R<-function (yy, method="L-BFGS-B", hess = FALSE, pool = TRUE,
 
       if (method == "L-BFGS-B")  {
         www[[k]]<-optim(init.par, fn = logL.joint.accel.decel.single.R, y = y, m = m, n = n, anc.values = anc.values, yy = yy,
-                   control = list(fnscale = -1, maxit=10000, trace = trace), method = "L-BFGS-B", hessian = hess, lower = lower.limit)
+                   control = list(fnscale = -1, maxit=10000, trace = trace), method = "L-BFGS-B", hessian = hess, lower = lower.limit, upper = upper.limit)
       }
 
       if (method == "Nelder-Mead")  {
@@ -96,7 +96,7 @@ opt.decel.single.R<-function (yy, method="L-BFGS-B", hess = FALSE, pool = TRUE,
       }
       if (method == "SANN")  {
         www[[k]]<-optim(init.par, fn = logL.joint.accel.decel.single.R, y = y, m = m, n = n, anc.values = anc.values, yy = yy,
-                   control = list(fnscale = -1, maxit=10000, trace = trace), method = "SANN" , hessian = hess, lower = lower.limit)
+                   control = list(fnscale = -1, maxit=10000, trace = trace), method = "SANN" , hessian = hess, lower = lower.limit, upper = upper.limit)
       }
       log.lik.tmp[k]<-www[[k]]$value
       }, error=function(e){cat("ERROR :",conditionMessage(e), "\n")})
@@ -129,7 +129,7 @@ opt.decel.single.R<-function (yy, method="L-BFGS-B", hess = FALSE, pool = TRUE,
 
     if (method == "L-BFGS-B")  {
       w<-optim(init.par, fn = logL.joint.accel.decel.single.R, y = y, m = m, n = n, anc.values = anc.values,  yy = yy,
-               control = list(fnscale = -1, maxit=10000, trace = trace), method = "L-BFGS-B", hessian = hess, lower = lower.limit)
+               control = list(fnscale = -1, maxit=10000, trace = trace), method = "L-BFGS-B", hessian = hess, lower = lower.limit, upper = upper.limit)
     }
 
     if (method == "Nelder-Mead")  {
@@ -138,7 +138,7 @@ opt.decel.single.R<-function (yy, method="L-BFGS-B", hess = FALSE, pool = TRUE,
     }
     if (method == "SANN")  {
       w<-optim(init.par, fn = logL.joint.accel.decel.single.R, y = y, m = m, n = n, anc.values = anc.values, yy = yy,
-               control = list(fnscale = -1, maxit=10000, trace = trace), method = "SANN" , hessian = hess, lower = lower.limit)
+               control = list(fnscale = -1, maxit=10000, trace = trace), method = "SANN" , hessian = hess, lower = lower.limit, upper = upper.limit)
     }
     
   }
@@ -151,7 +151,9 @@ opt.decel.single.R<-function (yy, method="L-BFGS-B", hess = FALSE, pool = TRUE,
   if (w$convergence == 10) converge<-"The search algorithm stopped as it did not make progress towards the optimal solution"
   if (w$convergence == 0) converge<-"Model converged successfully"
   if (w$convergence == 1) converge<-"The maximum number of iterations was reached and the search algorithm exited"
-
+  if (w$convergence == 51) converge<-"The model did not converge due to en error in L-BFGS-B. Reported estimates are not the maximum likelihood"
+  if (w$convergence == 52) converge<-"The model did not converge due to en error in L-BFGS-B. Reported estimates are not the maximum likelihood"
+  
   if (hess) {
     w$se <- sqrt(diag(-1 * solve(w$hessian)))
     SE.R1<-matrix(0, nrow=m, ncol=m)
