@@ -65,7 +65,7 @@ opt.decel.single.R.zero.corr<-function (yy, method="L-BFGS-B", hess = FALSE, poo
 
   init.par<-c(init.trait.var, anc.values, -1)
   lower.limit<-c(rep(0, length(init.trait.var)), rep(NA, (length(anc.values))), NA)
-  upper.limit<-c(rep(NA, (length(init.trait.var) +  length(anc.values))), 0)
+  upper.limit<-c(rep(NA, (length(init.trait.var) +  length(anc.values))), -1e-13)
 
 
   ### Start iterations from different starting values
@@ -84,7 +84,7 @@ opt.decel.single.R.zero.corr<-function (yy, method="L-BFGS-B", hess = FALSE, poo
 
       if (method == "L-BFGS-B")  {
         www[[k]]<-optim(init.par, fn = logL.joint.accel.decel.single.R.zero.corr, y = y, m = m, n = n, anc.values = anc.values, yy = yy,
-                   control = list(fnscale = -1, maxit=10000, trace = trace), method = "L-BFGS-B", hessian = hess, lower = lower.limit)
+                   control = list(fnscale = -1, maxit=10000, trace = trace), method = "L-BFGS-B", hessian = hess, lower = lower.limit, upper = upper.limit)
       }
 
       if (method == "Nelder-Mead")  {
@@ -93,7 +93,7 @@ opt.decel.single.R.zero.corr<-function (yy, method="L-BFGS-B", hess = FALSE, poo
       }
       if (method == "SANN")  {
         www[[k]]<-optim(init.par, fn = logL.joint.accel.decel.single.R.zero.corr, y = y, m = m, n = n, anc.values = anc.values, yy = yy,
-                   control = list(fnscale = -1, maxit=10000, trace = trace), method = "SANN" , hessian = hess, lower = lower.limit)
+                   control = list(fnscale = -1, maxit=10000, trace = trace), method = "SANN" , hessian = hess, lower = lower.limit, upper = upper.limit)
       }
       log.lik.tmp[k]<-www[[k]]$value
     }, error=function(e){cat("ERROR :",conditionMessage(e), "\n")})
@@ -126,7 +126,7 @@ if (length(na.exclude(log.lik.tmp)) == iterations){
 
     if (method == "L-BFGS-B")  {
       w<-optim(init.par, fn = logL.joint.accel.decel.single.R.zero.corr, y = y, m = m, n = n, anc.values = anc.values, yy = yy,
-               control = list(fnscale = -1, maxit=10000, trace = trace), method = "L-BFGS-B", hessian = hess, lower = lower.limit)
+               control = list(fnscale = -1, maxit=10000, trace = trace), method = "L-BFGS-B", hessian = hess, lower = lower.limit, upper = upper.limit)
     }
 
     if (method == "Nelder-Mead")  {
@@ -135,7 +135,7 @@ if (length(na.exclude(log.lik.tmp)) == iterations){
     }
     if (method == "SANN")  {
       w<-optim(init.par, fn = logL.joint.accel.decel.single.R.zero.corr, y = y, m = m, n = n, anc.values = anc.values, yy = yy,
-               control = list(fnscale = -1, maxit=10000, trace = trace), method = "SANN" , hessian = hess, lower = lower.limit)
+               control = list(fnscale = -1, maxit=10000, trace = trace), method = "SANN" , hessian = hess, lower = lower.limit, upper = upper.limit)
     }
     
   }
@@ -148,6 +148,8 @@ if (length(na.exclude(log.lik.tmp)) == iterations){
   if (w$convergence == 10) converge<-"The search algorithm stopped as it did not make progress towards the optimal solution"
   if (w$convergence == 0) converge<-"Model converged successfully"
   if (w$convergence == 1) converge<-"The maximum number of iterations was reached and the search algorithm exited"
+  if (w$convergence == 51) converge<-"The model did not converge due to en error in L-BFGS-B. Reported estimates are not the maximum likelihood"
+  if (w$convergence == 52) converge<-"The model did not converge due to en error in L-BFGS-B. Reported estimates are not the maximum likelihood"
   
   if (hess) {
     w$se <- sqrt(diag(-1 * solve(w$hessian)))
